import requests as r,re
def gw(t1,t2,s):
    try:
        regexPattern = t1 + '(.+?)' + t2
        str_found = re.search(regexPattern,s).group(1)
        return str_found.strip()
    except AttributeError:
        return 'Null'
def getname():
    s = r.post("https://api.name-fake.com/indonesia/female/",headers={'Content-Type':'application/x-www-form-urlencoded','User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.0.0 Safari/537.36'},data='con%5B%5D=id_ID&perc=100&miny=19&maxy=57')
    if s.text:
        return gw('<h2 style="text-align:center;padding: 1rem;">','</h2>',s.text)
    else: getname()




from setuptools import setup, find_packages

setup(
	name='raname',
	version='0.1',
	description='Random Name Generator | Use Free APIs',
	author='Itsaoda',
	author_email='febyzamsee@gmail.com',
	install_requires=[
		'requests>=2.23.0',
	],
	classifiers=[
		'Development Status :: 3 - Alpha',
		'Intended Audience :: Developers',
		'Topic :: Software Development :: Libraries :: Python Modules',
		'License :: OSI Approved :: MIT License',
		'Programming Language :: Python :: 3.11',
	],
)
